@@ -165,16 +165,6 @@ class NewTrxBase(BaseData):
             raise ParamValueError(err)
 
 
-@dataclass
-class NewTrxLike(NewTrxBase):
-    def __init__(self, trx_id, group_id, type="Like"):
-        if type not in ("Like", "Dislike"):
-            err = f"param type should be Like or Dislike"
-            raise ParamOverflowError(err)
-        object = {"id": trx_id}
-        super().__init__(type, group_id, object=object)
-
-
 @dataclass
 class WalletInfo:
     id: str
@@ -220,7 +210,7 @@ class ImgContent:
             self.name = utils.filename_init(path_bytes_string)
             file_bytes = utils.zip_image(path_bytes_string, kb)
             self.mediaType = filetype.guess(file_bytes).mime
-            self.content = file_bytes  # TODO:临时修改，要确认是否可行。base64.b64encode(file_bytes).decode("utf-8")
+            self.content = base64.b64encode(file_bytes).decode("utf-8")
 
     def person_img(self):
         return {"content": self.content, "mediaType": self.mediaType}
@@ -244,16 +234,6 @@ class PersonObj(BaseData):
             self.wallet = PersonWallets(self.wallet).rlt
 
 
-@dataclass
-class NewTrxPerson(NewTrxBase):
-    def __init__(self, group_id, name=None, image=None, wallet=None):
-        try:
-            person = PersonObj(name, image, wallet).to_dict()
-        except Exception as e:
-            raise ParamValueError(e)
-        super().__init__("Update", group_id, person=person)
-
-
 @dataclass
 class FileInfo:
     content: str
@@ -352,12 +332,9 @@ class ContentObj(BaseData):
                 if value and key not in ["type", "id", "content"]:
                     raise ParamOverflowError(f"del object got a no-need param {key}:{value}")
 
-
-@dataclass
-class NewTrxContent(NewTrxBase):
-    def __init__(self, group_id, **kwargs):
-        try:
-            object = ContentObj(**kwargs).to_dict()
-        except Exception as e:
-            raise ParamValueError(e)
-        super().__init__("Add", group_id, object=object)
+    def image_to_bytes(self):
+        if self.image:  # convert image to bytes
+            for i in self.image:
+                if isinstance(i["content"], str):
+                    i["content"] = base64.b64decode(i["content"])
+        return self
